@@ -1,4 +1,4 @@
-"""
+'''
 # Terraform CDK null Provider ~> 2.0
 
 This repo builds and publishes the Terraform null Provider bindings for [cdktf](https://cdk.tf).
@@ -35,12 +35,12 @@ This is mostly based on [projen](https://github.com/eladb/projen), which takes c
 
 ## cdktf-provider-project based on projen
 
-There's a custom [project builder](https://github.com/skorfmann/cdktf-provider-project) which encapsulate the common settings for all `cdktf` providers.
+There's a custom [project builder](https://github.com/terraform-cdk-providers/cdktf-provider-project) which encapsulate the common settings for all `cdktf` providers.
 
 ## provider version
 
 The provider version can be adjusted in [./.projenrc.js](./.projenrc.js).
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -74,7 +74,7 @@ class DataNullDataSource(
         lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
         provider: typing.Optional[cdktf.TerraformProvider] = None,
     ) -> None:
-        """
+        '''
         :param scope: -
         :param id: -
         :param has_computed_default: 
@@ -83,7 +83,7 @@ class DataNullDataSource(
         :param depends_on: 
         :param lifecycle: 
         :param provider: 
-        """
+        '''
         config = DataNullDataSourceConfig(
             has_computed_default=has_computed_default,
             inputs=inputs,
@@ -97,60 +97,60 @@ class DataNullDataSource(
 
     @jsii.member(jsii_name="outputs")
     def outputs(self, key: builtins.str) -> builtins.str:
-        """
+        '''
         :param key: -
-        """
-        return jsii.invoke(self, "outputs", [key])
+        '''
+        return typing.cast(builtins.str, jsii.invoke(self, "outputs", [key]))
 
     @jsii.member(jsii_name="resetHasComputedDefault")
     def reset_has_computed_default(self) -> None:
-        return jsii.invoke(self, "resetHasComputedDefault", [])
+        return typing.cast(None, jsii.invoke(self, "resetHasComputedDefault", []))
 
     @jsii.member(jsii_name="resetInputs")
     def reset_inputs(self) -> None:
-        return jsii.invoke(self, "resetInputs", [])
+        return typing.cast(None, jsii.invoke(self, "resetInputs", []))
 
     @jsii.member(jsii_name="synthesizeAttributes")
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
-        return jsii.invoke(self, "synthesizeAttributes", [])
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="id")
     def id(self) -> builtins.str:
-        return jsii.get(self, "id")
+        return typing.cast(builtins.str, jsii.get(self, "id"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="random")
     def random(self) -> builtins.str:
-        return jsii.get(self, "random")
+        return typing.cast(builtins.str, jsii.get(self, "random"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="hasComputedDefaultInput")
     def has_computed_default_input(self) -> typing.Optional[builtins.str]:
-        return jsii.get(self, "hasComputedDefaultInput")
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "hasComputedDefaultInput"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="inputsInput")
     def inputs_input(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
-        return jsii.get(self, "inputsInput")
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "inputsInput"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="hasComputedDefault")
     def has_computed_default(self) -> builtins.str:
-        return jsii.get(self, "hasComputedDefault")
+        return typing.cast(builtins.str, jsii.get(self, "hasComputedDefault"))
 
-    @has_computed_default.setter # type: ignore
+    @has_computed_default.setter
     def has_computed_default(self, value: builtins.str) -> None:
         jsii.set(self, "hasComputedDefault", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="inputs")
     def inputs(self) -> typing.Mapping[builtins.str, builtins.str]:
-        return jsii.get(self, "inputs")
+        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "inputs"))
 
-    @inputs.setter # type: ignore
+    @inputs.setter
     def inputs(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         jsii.set(self, "inputs", value)
 
@@ -178,14 +178,14 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
         has_computed_default: typing.Optional[builtins.str] = None,
         inputs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     ) -> None:
-        """
+        '''
         :param count: 
         :param depends_on: 
         :param lifecycle: 
         :param provider: 
         :param has_computed_default: 
         :param inputs: 
-        """
+        '''
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         self._values: typing.Dict[str, typing.Any] = {}
@@ -204,45 +204,45 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("count")
-        return result
+        return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
     def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("depends_on")
-        return result
+        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
 
     @builtins.property
     def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("lifecycle")
-        return result
+        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
 
     @builtins.property
     def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("provider")
-        return result
+        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
 
     @builtins.property
     def has_computed_default(self) -> typing.Optional[builtins.str]:
         result = self._values.get("has_computed_default")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def inputs(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         result = self._values.get("inputs")
-        return result
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -268,34 +268,34 @@ class NullProvider(
         *,
         alias: typing.Optional[builtins.str] = None,
     ) -> None:
-        """
+        '''
         :param scope: -
         :param id: -
         :param alias: Alias name.
-        """
+        '''
         config = NullProviderConfig(alias=alias)
 
         jsii.create(NullProvider, self, [scope, id, config])
 
     @jsii.member(jsii_name="resetAlias")
     def reset_alias(self) -> None:
-        return jsii.invoke(self, "resetAlias", [])
+        return typing.cast(None, jsii.invoke(self, "resetAlias", []))
 
     @jsii.member(jsii_name="synthesizeAttributes")
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
-        return jsii.invoke(self, "synthesizeAttributes", [])
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="aliasInput")
     def alias_input(self) -> typing.Optional[builtins.str]:
-        return jsii.get(self, "aliasInput")
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="alias")
     def alias(self) -> typing.Optional[builtins.str]:
-        return jsii.get(self, "alias")
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "alias"))
 
-    @alias.setter # type: ignore
+    @alias.setter
     def alias(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "alias", value)
 
@@ -307,18 +307,18 @@ class NullProvider(
 )
 class NullProviderConfig:
     def __init__(self, *, alias: typing.Optional[builtins.str] = None) -> None:
-        """
+        '''
         :param alias: Alias name.
-        """
+        '''
         self._values: typing.Dict[str, typing.Any] = {}
         if alias is not None:
             self._values["alias"] = alias
 
     @builtins.property
     def alias(self) -> typing.Optional[builtins.str]:
-        """Alias name."""
+        '''Alias name.'''
         result = self._values.get("alias")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -348,7 +348,7 @@ class Resource(
         lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
         provider: typing.Optional[cdktf.TerraformProvider] = None,
     ) -> None:
-        """
+        '''
         :param scope: -
         :param id: -
         :param triggers: 
@@ -356,7 +356,7 @@ class Resource(
         :param depends_on: 
         :param lifecycle: 
         :param provider: 
-        """
+        '''
         config = ResourceConfig(
             triggers=triggers,
             count=count,
@@ -369,30 +369,30 @@ class Resource(
 
     @jsii.member(jsii_name="resetTriggers")
     def reset_triggers(self) -> None:
-        return jsii.invoke(self, "resetTriggers", [])
+        return typing.cast(None, jsii.invoke(self, "resetTriggers", []))
 
     @jsii.member(jsii_name="synthesizeAttributes")
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
-        return jsii.invoke(self, "synthesizeAttributes", [])
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="id")
     def id(self) -> builtins.str:
-        return jsii.get(self, "id")
+        return typing.cast(builtins.str, jsii.get(self, "id"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="triggersInput")
     def triggers_input(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
-        return jsii.get(self, "triggersInput")
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "triggersInput"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="triggers")
     def triggers(self) -> typing.Mapping[builtins.str, builtins.str]:
-        return jsii.get(self, "triggers")
+        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "triggers"))
 
-    @triggers.setter # type: ignore
+    @triggers.setter
     def triggers(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         jsii.set(self, "triggers", value)
 
@@ -418,13 +418,13 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
         provider: typing.Optional[cdktf.TerraformProvider] = None,
         triggers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     ) -> None:
-        """
+        '''
         :param count: 
         :param depends_on: 
         :param lifecycle: 
         :param provider: 
         :param triggers: 
-        """
+        '''
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
         self._values: typing.Dict[str, typing.Any] = {}
@@ -441,40 +441,40 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("count")
-        return result
+        return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
     def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("depends_on")
-        return result
+        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
 
     @builtins.property
     def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("lifecycle")
-        return result
+        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
 
     @builtins.property
     def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
-        """
+        '''
         :stability: experimental
-        """
+        '''
         result = self._values.get("provider")
-        return result
+        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
 
     @builtins.property
     def triggers(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         result = self._values.get("triggers")
-        return result
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
